# JJ 2019-02-18: ticket cache checks and home directory population
if [ "$HOME" = "/home/$USER" ] && 
    [ "x$HYADHOME" = x ] && 
    [ $(id -u) -gt 1000000 ]; then

  # Use the CIFS DFS mount as HYADHOME
  c=$(echo "$USER" | cut -c1)
  export HYADHOME=/home/ad/home/$c/$USER
  unset c
  
  if [ -e /etc/cubbli/flags/use-ad-home -a "x$KRB5CCNAME" = "x" ]; then
    uid=$(id -u)
    # Try to make sure that we have a kerberos ticket cache.
    unset KRB5CCNAME
    for ticket in "/tmp/krb5cc_${uid}_"* ; do
      # Check for symlink and file name trickery
      if [ "$(stat --format "%F %u" $ticket 2>/dev/null)" = "regular file $uid" ]; then
        export KRB5CCNAME=FILE:$ticket
	# Check correct kerberos domain for HYAD
	if ! klist | fgrep -q "krbtgt/AD.HELSINKI.FI@AD.HELSINKI.FI"; then
	  continue
	fi
	# use the ticket, if it can be renewed for 5 minutes
	krenew -H 5 && break
	unset KRB5CCNAME
      fi
    done
    unset ticket
    unset uid

    if [ "x$KRB5CCNAME" = "x" ]; then
      echo "You have succesfully logged in, but don't have a valid Kerberos ticket."
      echo "More details here: https://wiki.helsinki.fi/x/8YbLDw"
      echo "Login with your AD password to get a new Kerberos ticket:"
      export KRB5CCNAME=$(ssh -a -k -o "StrictHostKeyChecking off" -o "UserKnownHostsFile /dev/null"  $(uname -n) 'echo $KRB5CCNAME' 2>/dev/null)
    fi

    if [ "x$KRB5CCNAME" = "x" ]; then
      echo "Failed to get a kerberos ticket. Logging you out now."
      exit 1
    fi
    # Now this might work
    cd
  fi

  # If the symlink trick is in use, create and populate symlink target directory
  if [ -L "$HOME" ]; then
    linux_home="$(readlink -m $HOME)"
    if echo "$linux_home" | egrep -q /home/ad/ ; then
      # We are in AD home: populate it
      for d in Desktop Documents Downloads; do
        mkdir -p "$HYADHOME/$d"
        [ -L $d -o ! -e $d ] && ln -nfs $HYADHOME/$d $d
      done
    fi
    unset linux_home
  fi
  #  if [ "$PWD" = "/" -o "$PWD" = "$linux_home" ]; then
  #    # reset the ugly looking full path home directory or missing link
  #    cd $HOME
  #  fi

#    if [ -d .cache -a ! -L .cache ]; then
#      if oldcache=$(mktemp -d .cache.cubbli.tmp.XXXXXXXXXX); then
#        mv .cache "$oldcache"
#      else
#        rm -rf .cache
#      fi
#    fi
#    rm -rf .cache.cubbli.tmp.?????????? > /dev/null 2>&1 &
#    disown
#    localcache="$TMPDIR/.cache.cubbli"
#    if mkdir -m 700 -p "$localcache" && [ a"$(stat -c "%u" "$localcache")" = a"$(id -u)" ] ; then
#      touch "$localcache" # Dummy for having a non-empty if
#      ln -sf "$TMPDIR"/.cache.cubbli .cache
#    else
#      rm -f .cache
#      mkdir -m 700 -p .cache
#    fi
#    unset oldcache
#    unset localcache
#  fi

fi

if [ ! -f ~/.hushlogin ]; then
  /usr/bin/cubbli-home-dir show
fi
